@@ -18,28 +18,27 @@
 #include <string.h>
 #include "about.h"
 #include "tuievent.h"
-
-//стрингификатор
-#define XSTR(S)		STR(S)
-#define STR(S)		#S
+#include "commondef.h"
 
 
 AboutWin::AboutWin(int rows, int cols) : NGroup(NRect(rows, cols, getmaxy(stdscr)/2-rows/2,getmaxx(stdscr)/2-cols/2))
 {
     modalflag = true;
     caption = strdup(" BOINCTUI ");
-    resize(10,getwidth());
-    wattrset(win,getcolorpair(COLOR_WHITE, COLOR_BLACK) | A_BOLD);
+    resize(12,getwidth());
+    wattrset(win,getcolorpair(COLOR_WHITE, getbgcolor()) | A_BOLD);
     if(asciilinedraw == 1)
 	wborder(win, '|', '|', '-', '-', '+', '+', '+', '+');
     else
 	box(win,0,0);
-    mvwprintw(win,0,getwidth()/2-(strlen(caption)/2),caption);
+    mvwprintw(win,0,getwidth()/2-(strlen(caption)/2),"%s",caption);
     char buf[1024];
     snprintf(buf,sizeof(buf),"%s ver %s","BOINC Client manager", XSTR(VERSION));
-    mvwprintw(win,3,getwidth()/2-(strlen(buf)/2),buf);
+    mvwprintw(win,3,getwidth()/2-(strlen(buf)/2),"%s",buf);
     mvwprintw(win,5,getwidth()/2-(strlen("(c) Sergey Suslov")/2),"(c) Sergey Suslov");
     mvwprintw(win,6,getwidth()/2-(strlen("suleman1971@gmail.com")/2),"suleman1971@gmail.com");
+    mvwprintw(win,7,getwidth()/2-(strlen("Community PRs included by")/2),"Community PRs included by");
+    mvwprintw(win,8,getwidth()/2-(strlen("Mark Pentler - GitHub: mpentler")/2),"Mark Pentler - GitHub: mpentler");
 }
 
 
